@@ -29,7 +29,7 @@ if __name__ == '__main__':
         'action',
         const='generate',
         nargs='?',
-        choices=['init', 'list', 'create', 'describe', 'deploy']
+        choices=['init', 'list', 'create', 'describe', 'deploy', 'serve']
     )
     parser_endpoint.add_argument('endpoint', const='generate', nargs='?')
     parser_endpoint.set_defaults(which='endpoints')
