@@ -58,7 +58,7 @@ class Endpoint:
                 'ENV': 'production',
             }
         }
-        env = yaml.dump(env, default_flow_style=False)
+        env = yaml.dump(env, explicit_start=True, sort_keys=False, indent=2, width=1000)
         env = env.replace("'{{", "{{").replace("}}'", '}}')
         return env
 
@@ -109,9 +109,9 @@ def init_file_structure(config: Config):
         Path(base_dir, 'endpoints', 'src', 'services').mkdir()
         with open(f"{base_dir}/endpoints/src/services/__init__.py", "w") as file:
             file.write("""from . import docs
-from . import hello_world
+from . import health
 """)
-        endpoint_create(base_dir, 'hello_world')
+        endpoint_create(base_dir, 'health')
         endpoint_create(base_dir, 'docs')
 
     if not Path(base_dir, 'api.yaml').exists():
@@ -226,7 +226,7 @@ def cli_main(args, config: Config) -> int:
             ),
             steps.StepCommand(
                 shlex.split("secrethub inject -i env.temp.yaml -o env.yaml"),
-                work_dir=f'{config.base_dir}/endpoints/{endpoint.operation_id}',
+                work_dir=f'{config.base_dir}/build/endpoints/{endpoint.operation_id}',
             ),
             steps.StepCommand(
                 shlex.split(runtime.command),
@@ -238,3 +238,24 @@ def cli_main(args, config: Config) -> int:
             return rc
         print(helpers.bcolors.OKGREEN + f'Deployed endpoint {endpoint.operation_id} success' + helpers.bcolors.ENDC)
         return 0
+    elif args.action == 'serve':
+        endpoints = [x for x in endpoint_list(config) if x.operation_id == args.endpoint]
+        if len(endpoints) == 0:
+            print(
+                helpers.bcolors.FAIL
+                + f'Endpoint {args.endpoint} not found'
+                + helpers.bcolors.ENDC
+            )
+            return 1
+        endpoint = endpoints[0]
+
+        print('# Serve')
+        manager = steps.Manager(config, [
+            steps.StepCommand(
+                shlex.split(f"functions-framework --source='{endpoint.operation_id}.py' --target main --debug --port=8004"),
+                work_dir=f'{config.base_dir}/endpoints',
+            ),
+        ], simulate=args.simulate)
+        rc = manager.run()
+        if rc != 0:
+            return rc
